==> eam-wshub-proxyclient-11.6-0-sources.jar: net/datastream/schemas/mp_fields/SCHEDULEBY.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;choice>
 *         &lt;element name="SCHEDULEBYTRADE" type="{http://schemas.datastream.net/MP_fields}SCHEDULEBYTRADE_Type"/>
 *         &lt;element name="SCHEDULEBYPERSON" type="{http://schemas.datastream.net/MP_fields}PERSONID_Type"/>
 *       &lt;/choice>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "schedulebytrade",
    "schedulebyperson"
})
@XmlRootElement(name = "SCHEDULEBY")
public class SCHEDULEBY {

    @XmlElement(name = "SCHEDULEBYTRADE")
    protected SCHEDULEBYTRADE_Type schedulebytrade;
    @XmlElement(name = "SCHEDULEBYPERSON")
    protected PERSONID_Type schedulebyperson;

    /**
     * Obtient la valeur de la propriété schedulebytrade.
     * 
     * @return
     *     possible object is
     *     {@link SCHEDULEBYTRADE_Type }
     *     
     */
    public SCHEDULEBYTRADE_Type getSCHEDULEBYTRADE() {
        return schedulebytrade;
    }

    /**
     * Définit la valeur de la propriété schedulebytrade.
     * 
     * @param value
     *     allowed object is
     *     {@link SCHEDULEBYTRADE_Type }
     *     
     */
    public void setSCHEDULEBYTRADE(SCHEDULEBYTRADE_Type value) {
        this.schedulebytrade = value;
    }

    /**
     * Obtient la valeur de la propriété schedulebyperson.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getSCHEDULEBYPERSON() {
        return schedulebyperson;
    }

    /**
     * Définit la valeur de la propriété schedulebyperson.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setSCHEDULEBYPERSON(PERSONID_Type value) {
        this.schedulebyperson = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/SCHEDULEBY.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;choice>
 *         &lt;element name="SCHEDULEBYTRADE" type="{http://schemas.datastream.net/MP_fields}SCHEDULEBYTRADE_Type"/>
 *         &lt;element name="SCHEDULEBYPERSON" type="{http://schemas.datastream.net/MP_fields}PERSONID_Type"/>
 *       &lt;/choice>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "schedulebytrade",
    "schedulebyperson"
})
@XmlRootElement(name = "SCHEDULEBY")
public class SCHEDULEBY {

    @XmlElement(name = "SCHEDULEBYTRADE")
    protected SCHEDULEBYTRADE_Type schedulebytrade;
    @XmlElement(name = "SCHEDULEBYPERSON")
    protected PERSONID_Type schedulebyperson;

    /**
     * Gets the value of the schedulebytrade property.
     * 
     * @return
     *     possible object is
     *     {@link SCHEDULEBYTRADE_Type }
     *     
     */
    public SCHEDULEBYTRADE_Type getSCHEDULEBYTRADE() {
        return schedulebytrade;
    }

    /**
     * Sets the value of the schedulebytrade property.
     * 
     * @param value
     *     allowed object is
     *     {@link SCHEDULEBYTRADE_Type }
     *     
     */
    public void setSCHEDULEBYTRADE(SCHEDULEBYTRADE_Type value) {
        this.schedulebytrade = value;
    }

    /**
     * Gets the value of the schedulebyperson property.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getSCHEDULEBYPERSON() {
        return schedulebyperson;
    }

    /**
     * Sets the value of the schedulebyperson property.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setSCHEDULEBYPERSON(PERSONID_Type value) {
        this.schedulebyperson = value;
    }

}
